@@ -8,7 +8,7 @@ import os
 import numpy as np
 from tqdm import tqdm
 
-from .model import Params
+from .model import Params, summarize_model
 from .simulator import Simulator, load_plugins
 from .report import summarize_simulations
 
@@ -70,6 +70,7 @@ def parse_args(args=None):
     parser.add_argument(
         '--symptomatic-transmissibility-model',
         nargs='+',
+        default=['piecewise'],
         help='''Model used for asymptomatic cases with parameters. The default model
             normal has a duration of 8 days after incubation, and a peak happens at 2/3 of
             incubation. An alternative piece wise model has a stage of no infectivity, a stage
@@ -81,6 +82,7 @@ def parse_args(args=None):
     parser.add_argument(
         '--asymptomatic-transmissibility-model',
         nargs='+',
+        default=['piecewise'],
         help='''Model used for asymptomatic cases with parameters. The default model
             normal has a duration of 12 and peaks at 4.8 day. The piecewise model has
             a stage of no infectivity, a stage for increasing and a stage for decreasing
@@ -162,6 +164,19 @@ def parse_args(args=None):
         type=int,
         help='Number of process to use for simulation. Default to number of CPU cores.'
     )
+    parser.add_argument(
+        '-v',
+        '--version',
+        action='store_true',
+        help='Print version information'
+    )
+    parser.add_argument(
+        '--summarize-model',
+        action='store_true',
+        help='''If specified, output key statistics calculated such as mean serial interval directly
+            from model parameters. No simulation will actually be executed if this parameter is
+            specified.'''
+    )
     parser.add_argument(
         '--summary-report',
         help='''Generate a summary report and write to the specified file,
@@ -227,6 +242,14 @@ class Worker(multiprocessing.Process):
 def main(argv=None):
     """Console script for covid19_outbreak_simulator."""
     args = parse_args(argv)
+    if args.version:
+        from . import __version__
+        print(f'COVID10 Outbreak Simulator version {__version__}')
+        sys.exit(0)
+    if args.summarize_model:
+        summarize_model(Params(args))
+        sys.exit(0)
+
     tasks = multiprocessing.JoinableQueue()
     results = multiprocessing.Queue()
     if args.plugin:
@@ -256,10 +279,9 @@ def main(argv=None):
                 f'Option --stop-if currently only supports t>TIME to stop after certain time point.'
             )
 
-
-
     completed_ids = set()
     append_mode = os.path.isfile(args.logfile)
+    has_header = False
     if append_mode:
         with open(args.logfile, 'r') as lf:
             for line in lf:
@@ -269,7 +291,10 @@ def main(argv=None):
                         completed_ids.add(id)
                 except:
                     # might be $ or "id"
-                    pass
+                    has_header = True
+    # malformed log file
+    if not has_header:
+        append_mode = False
 
     if len(completed_ids) == args.repeats:
         print(f'All simulations have been performed. Remove {args.logfile} if you would like to rerun.')
