@@ -1,11 +1,13 @@
+import os
 import re
 
 import numpy as np
+import pandas as pd
 from scipy.optimize import bisect
 from scipy.stats import norm
 from covid19_outbreak_simulator.utils import as_float, as_int
 from fnmatch import fnmatch
-
+import yaml
 
 class Params:
     def __init__(self, args=None):
@@ -23,6 +25,18 @@ class Params:
         self.groups = {}
         self.set_params(args)
 
+    def __str__(self):
+        def float_representer(dumper, value):
+            text = '{0:.4f}'.format(value)
+            return dumper.represent_scalar(u'tag:yaml.org,2002:float', text)
+        yaml.add_representer(float, float_representer)
+
+        val = {x:list(y) if isinstance(y, set) else y for x,y in self.__dict__.items() if x != 'params'}
+        if 'groups' in val and len(val['groups']) == 1:
+            val['groups'] = {'Unnamed': list(val['groups'].values())[0]}
+        return yaml.dump(val, sort_keys=True, indent=4)
+
+
     def set(self, param, prop, value):
         if param not in self.params:
             raise ValueError(f"Unrecgonzied parameter {param}")
@@ -214,10 +228,10 @@ class Params:
     # a, b
 
     def set_symptomatic_transmissibility_model(self, val):
-        if not val or val[0] == "normal":
-            self.symptomatic_transmissibility_model = dict(name="normal")
-        elif val[0] != "piecewise":
+        if not val or val[0] not in ('normal', 'piecewise'):
             raise ValueError("Only a normal and a piecewise model is supported")
+        elif val[0] == "normal":
+            self.symptomatic_transmissibility_model = dict(name="normal")
         elif len(val) == 1:
             self.symptomatic_transmissibility_model = dict(
                 name=val[0],
@@ -253,10 +267,10 @@ class Params:
     # [n + rng.quantile(x) for x in [0.1, 0.2, 0.3, 0.4, 0.5, 0.6, 0.7, 0.8, 0.9, 0.95, 0.975]]
 
     def set_asymptomatic_transmissibility_model(self, val):
-        if not val or val[0] == "normal":
-            self.asymptomatic_transmissibility_model = dict(name="normal")
-        elif val[0] != "piecewise":
+        if not val or val[0] not in ('normal', 'piecewise'):
             raise ValueError("Only a normal and a piecewise model is supported")
+        if val[0] == "normal":
+            self.asymptomatic_transmissibility_model = dict(name="normal")
         elif len(val) == 1:
             self.asymptomatic_transmissibility_model = dict(
                 name=val[0],
@@ -668,4 +682,100 @@ class Model(object):
         y = y / sum(y) * R0
         # we assume that viral load is 2 times the transmissibility
         # for asymptomatic cases.
-        return x, y
\ No newline at end of file
+        return x, y
+
+
+def print_stats(data, name):
+    series = pd.Series(data)
+    print('\n' + name + ':')
+    print(f'            mean:  {series.mean():.4f}')
+    print(f'             std:  {series.std():.4f}')
+    for q in (0.025, 0.05, 0.5, 0.95, 0.975):
+        print(f'  {q*100:4.1f}% quantile:  {series.quantile(q):.4f}')
+
+def sample_prop_asymp_carriers(model, N=1000):
+    asym_carriers = []
+    for i in range(N):
+        model.draw_prop_asym_carriers()
+        asym_carriers.append(model.draw_is_asymptomatic())
+    return asym_carriers
+
+
+def summarize_model(params):
+    from .population import Individual
+    print('Parameters (in YAML format)\n')
+    print(params)
+    print()
+    #
+    print('Properties:')
+    N = 5000
+    model = Model(params)
+    print_stats(sample_prop_asymp_carriers(model, N),
+        'Proportion of asymptomatic carriers')
+
+    #
+    model.params.set('prop_asym_carriers', 'loc', 0)
+    model.params.set('prop_asym_carriers', 'scale', 0)
+    print_stats([model.draw_random_incubation_period() for x in range(N)],
+        'Incubation period')
+
+    print_stats([model.draw_random_r0(symptomatic=True) for x in range(N)],
+        'Production Number (Symptomatic)')
+    print_stats([model.draw_random_r0(symptomatic=False) for x in range(N)],
+        'Production Number (Asymptomatic)')
+
+    model.params.set('prop_asym_carriers', 'loc', 0)
+    model.params.set('prop_asym_carriers', 'scale', 0)
+
+    cp = []
+    du = []
+    with open(os.devnull, 'w') as logger:
+        logger.id = 1
+        model.draw_prop_asym_carriers()
+        for i in range(N):
+            ind = Individual(id='0', susceptibility=1, model=model, logger=logger)
+            evts = ind.symptomatic_infect(time=0, by=None,
+                                        handle_symptomatic=['keep'])
+            cp.append(ind.communicable_period())
+            du.append(ind.total_duration())
+
+    model.params.set('prop_asym_carriers', 'loc', 1)
+    model.params.set('prop_asym_carriers', 'scale', 0)
+
+    acp = []
+    adu = []
+    with open(os.devnull, 'w') as logger:
+        logger.id = 1
+        model.draw_prop_asym_carriers()
+        for i in range(N):
+            ind = Individual(id='0', susceptibility=1, model=model, logger=logger)
+            evts = ind.asymptomatic_infect(time=0, by=None,
+                                        handle_symptomatic=['keep'])
+            acp.append(ind.communicable_period())
+            adu.append(ind.total_duration())
+
+    print_stats(cp, 'Communicable Period (Symptomatic)')
+    print_stats(du, 'Total Duration (Symptomatic)')
+    print_stats(acp, 'Communicable Period (Asymptomatic)')
+    print_stats(adu, 'Total Duration (Asymptomatic)')
+
+    model.params.set('prop_asym_carriers', 'loc', 0)
+    model.params.set('prop_asym_carriers', 'scale', 0)
+
+    si = []
+    gt = []
+
+    with open(os.devnull, 'w') as logger:
+        logger.id = 1
+        model.draw_prop_asym_carriers()
+        for i in range(N):
+            ind = Individual(id='0', susceptibility=1, model=model, logger=logger)
+            evts = ind.symptomatic_infect(time=0, by=None,
+                                        handle_symptomatic=['keep'])
+            for evt in [x for x in evts if x.action.name == 'INFECTION']:
+                gt.append(evt.time)
+                si.append(evt.time + ind.model.draw_random_incubation_period() - ind.incubation_period)
+                break
+
+    print_stats(si, 'Serial Interval')
+    print_stats(gt, 'Generation Time')
